@@ -1,12 +1,13 @@
-from sqlalchemy.ext.asyncio import create_async_engine, AsyncConnection
-from patches import patch_async_connection_init
+from sqlalchemy.ext.asyncio import create_async_engine
+from sqlalchemy.ext.asyncio import AsyncConnection
 from .logger_config import logger
 from dotenv import dotenv_values
 from threading import Lock
 import sqlalchemy
-import weakref
 import aioodbc
+import weakref
 
+# Mapping of required fields for each supported database type
 REQUIRED_FIELDS = {
     "sqlite": ["NAME"],
     "postgresql": ["USER", "PASSWORD", "HOST", "NAME"],
@@ -15,6 +16,7 @@ REQUIRED_FIELDS = {
     "oracle": ["USER", "PASSWORD", "HOST", "NAME"],
 }
 
+# Connection string templates for supported databases
 CONNECTION_STRINGS = {
     "sqlite": "sqlite+aiosqlite:///{NAME}",
     "postgresql": "postgresql+asyncpg://{USER}:{PASSWORD}@{HOST}/{NAME}",
@@ -23,13 +25,39 @@ CONNECTION_STRINGS = {
     "oracle": "oracle+oracledb://{USER}:{PASSWORD}@{HOST}/{NAME}"
 }
 
-patch_async_connection_init()
+# Apply patches to ensure connection management works as expected
+def patch_async_connection_init():
+    original_init = AsyncConnection.__init__
 
+    def connection_init_hook(connection_self, *args, **kwargs):
+        weakref.finalize(connection_self, lambda: None)  # Ensures clean-up of AsyncConnection
+        return original_init(connection_self, *args, **kwargs)
+
+    AsyncConnection.__init__ = connection_init_hook
+
+""" Builds a connection string for a given database type and environment configuration.
+
+Args:
+    db_type (str): The type of database (e.g., 'sqlite', 'postgresql').
+    env (dict): A dictionary of environment variables for database configuration.
+
+Returns:
+    str: A formatted connection string for the specified database.
+"""
 def _build_connection_string(db_type, env):
     db_type = db_type.lower()
     _check_required_fields(env, db_type)
     return CONNECTION_STRINGS[db_type].format(**env)
 
+""" Validates the presence of required fields in the environment configuration.
+
+Args:
+    env (dict): A dictionary containing environment variables.
+    db_type (str): The type of database to validate fields for.
+
+Raises:
+    KeyError: If required fields are missing or empty.
+"""
 def _check_required_fields(env, db_type):
     for field in REQUIRED_FIELDS[db_type]:
         if not env.get(field) or not env[field].strip():
@@ -37,27 +65,45 @@ def _check_required_fields(env, db_type):
             logger.error(error_message)
             raise KeyError(error_message)
 
+# Apply patches to ensure connection management works as expected
+patch_async_connection_init()
+
+"""Manages asynchronous database engine connections."""
 class EngineManager:
 
+    """ Initializes the EngineManager class.
+
+        Sets up thread safety and patches `aioodbc` connections for tracking.
+        """
     def __init__(self):
         self._engines = {}
         self._lock = Lock()
         self._all_aioodbc_connections = []
         self._patch_aioodbc_connect()
 
+    """ Patches aioodbc.connect to track active AioODBC connections."""
     def _patch_aioodbc_connect(self):
         original_aioodbc_connect = aioodbc.connect
         async def patched_aioodbc_connect(*args, **kwargs):
             conn = await original_aioodbc_connect(*args, **kwargs)
-            self._all_aioodbc_connections.append(conn)
+            self._all_aioodbc_connections.append(conn) # Track connections for clean-up
             return conn
 
         aioodbc.connect = patched_aioodbc_connect
 
+    """ Retrieves or creates an asynchronous database engine.
+
+        Args:
+            env_file_name (str, optional): Path to an environment configuration file.
+                                           Defaults to ".env".
+
+        Returns:
+            sqlalchemy.ext.asyncio.AsyncEngine: An asynchronous SQLAlchemy engine.
+        """
     def get_engine(self, env_file_name=None):
         env_file = env_file_name or ".env"
         if env_file not in self._engines:
-            with self._lock:
+            with self._lock: # Thread safety for engine creation
                 if env_file not in self._engines:
                     env = dotenv_values(env_file)
 
@@ -81,6 +127,14 @@ class EngineManager:
                         raise
         return self._engines[env_file]
 
+    """ Establishes an asynchronous database connection.
+
+        Args:
+            env_file_name (str, optional): Path to an environment configuration file.
+
+        Returns:
+            sqlalchemy.ext.asyncio.AsyncConnection: An active asynchronous database connection.
+        """
     async def connect_db(self, env_file_name=None):
         engine = self.get_engine(env_file_name)
         try:
@@ -96,10 +150,8 @@ class EngineManager:
             logger.error(f"Unexpected Error: {e}")
             raise
 
+    """ Closes all active database engines and lingering connections."""
     async def close_engines(self):
-        """
-        Closes all active database engines and attempts to forcibly close lingering connections.
-        """
         for env_file, engine in self._engines.items():
             logger.info(f"Disposing engine for: {env_file}")
             await engine.dispose()
